@@ -701,10 +701,11 @@ class IrcBot(object):
                 return
 
             if message['type'] == 'nickchange':
-                if message['nick'] in self.channel_names[message['channel']]:
-                    self.channel_names[message['channel']].remove(message['nick'])
-                if message['nickchange'] not in self.channel_names[message['channel']]:
-                    self.channel_names[message['channel']].append(message['nickchange'])
+                for channel in self.channel_names:
+                    if message['nick'] in self.channel_names[channel]:
+                        self.channel_names[channel].remove(message['nick'])
+                    if message['nickchange'] not in self.channel_names[channel]:
+                        self.channel_names[channel].append(message['nickchange'])
 
             if message['type'] == 'join':
                 if not message['channel'] in self.channel_names:
